@@ -19,8 +19,6 @@ Boston, MA 02110-1301, USA.
 */
 
 #include <qlabel.h>
-#include <q3vbox.h>
-#include <q3groupbox.h>
 #include <qlayout.h>
 #include <qcombobox.h>
 
