@@ -30,13 +30,15 @@ class PluginWebArchiver : public KParts::Plugin
   Q_OBJECT
 
  public:
-  PluginWebArchiver( QObject* parent, 
+  PluginWebArchiver( QObject* parent,
                      const QStringList & );
   virtual ~PluginWebArchiver();
 
  public slots:
    void slotSaveToArchive();
 
+private:
+   KConfig *m_config;
 };
 
 #endif
